@@ -6,19 +6,9 @@ import time
 from functools import cached_property, partial
 from typing import Any, Callable, Optional
 
-try:
-    import psutil
-except ImportError:
-    psutil = None  # type: ignore
-
 
 logger = _logging.getLogger(__name__)
 
-if not psutil:
-    logger.warning(
-        "Unable to import `psutil`. Most likely related to: "
-        "https://github.com/bazelbuild/rules_python/issues/622")
-
 
 class ADebugLogging:
 
@@ -127,7 +117,7 @@ class ADebugLogging:
             result_info = formatter(
                 start, result, time_taken, result_info)
         self.log(instance).debug(
-            f"{self.name}{self._cpu_info} returns {result_info}")
+            f"{self.name} returns {result_info}")
         return result
 
     def log_debug_complete_iter(self, start, count):
@@ -141,16 +131,9 @@ class ADebugLogging:
             result_info = formatter(
                 start, count, time_taken, result_info)
         self.log(instance).debug(
-            f"{self.name}{self._cpu_info} "
+            f"{self.name} "
             f"generated {result_info}")
 
-    @property
-    def _cpu_info(self):
-        return (
-            f" (cpu: {psutil.Process(os.getpid()).cpu_num()})"
-            if psutil and self._show_cpu
-            else "")
-
 
 class ATraceLogging(ADebugLogging):
 
